# islatu

[![Documentation Status](https://readthedocs.org/projects/islatu/badge/?version=latest)](https://islatu.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/arm61/islatu.svg?branch=master)](https://travis-ci.org/arm61/islatu)
[![Coverage Status](https://coveralls.io/repos/github/arm61/islatu/badge.svg?branch=master)](https://coveralls.io/github/arm61/islatu?branch=master)

X-ray reflectometry reduction from Diamond Light Source 

### Install 

```
python setup.py build 
python setup.py install 
pytest
```
